% ****************************************************
% main program for demonstration how to call the 
% procedure lnpr (Lomb-Scargle Periodogram for Reconstruction)  
% ****************************************************

% preparation of artificial time serie y(x):
% --------------------------------------------------
days=60 ;
ndp=24*3;   %points per day (sampling time 20 min)
n=days*ndp;  
t1=5*ndp     ; %start point    
offset=20;

x=t1+(1:n);
y=zeros(n,1);
dim=n;

a=[3,2,3,2,3];                    %input amplitude 
del=[.25,.5,.75,.1,.1]*2*pi;       %;      phase

ome=days*[.3,.7,1.2,2,3]    ;        %;   periods [cyc/day]
om=2*pi*ome/n;
nn=length(a);


for j=1:nn         %; superposition of the waves
	y=y+a(j)*cos(om(j)*x'+del(j));
end

xc=x;  %saving of the clear series (signal curve without noise and gaps)
yc=y;
	
	
y=y+2.5*mean(a)*randn(n,1) ;   %  plus  noise 

%generation of gaps in y(x):
igap=1
if igap
	ig1=fix(n/3)
	ig2=ig1+450;
	x(ig1:ig2)=[];
	y(ig1:ig2)=[];
	ig1=fix(2*n/4)
	ig2=ig1+150;
	x(ig1:ig2)=[];
	y(ig1:ig2)=[];
end
%;---------------------------------------------------
xo=x;    %  saving of series yo(xo) with gaps and noise
yo=y;

y=y-mean(y);
fa=1;
win=1;   
if win
	window=hamming(length(y)); 
	y=y.*window;     % reconstruction is a bit better with windowing
	fa=2;     
end

y=y+offset;     % general case: series is not centered at 0  
yo=yo+offset;
yc=yc+offset; 


% end of preparation of artificial time serie y(x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%!!!!!!!!!!!!!!  call of procedure  !!!!!!!!!!!!!!!

[wk1,wk2,ph,vari,hifac,ofac,F,teta]=lspr(x,y);

%;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


%amplitude
am=fa*sqrt(wk2*2*vari*2/n); % not considered here 




%manipulation of the Fourier spectrum F:
Fo=F;
conf=98;   %confidence level 
alpha=(100-conf)/2/100;
a=norminv([alpha,1-alpha],0,1);   %
level=a(2) ; 
nf=length(F);
spec=F(2:fix(nf/4));  %consider only a part of the spectrum for confidence estimation
noise_limit=sqrt(level*mean(spec.*conj(spec))); %  level*mean power of spectra

% or just a free choice in case of synthetic data:
level=max(abs(F(2:end)))/3;
noise_limit=level;


ind=find(abs(F) < noise_limit) ;
F(ind)=0; F(1)=Fo(1);           %removal of noise
%-------------------
%spectrum plot
figure(2)
fs=15
lw=2
clf
%;frequency axis in cycles per day
dim=length(wk1);
xdif=max(x)-min(x);
f=wk1*xdif/days;



ao_spec=abs(Fo(2:dim+1))*2/length(F);
plot(f,ao_spec,'r','linewidth',1.2)
hold on
a_spec=abs(F(2:dim+1))*2/length(F);
plot(f,a_spec,'*','markersize',8)
set(gca,'xscale','log')
xli=[1e-1,10];
xlim(xli);
ylim([0,max(ao_spec)*1.2])
yli=get(gca,'ylim');
plot(xli,noise_limit*2/length(F)*[1,1],'k--','linewidth',2)
ome1=ome/days;
for i=1:nn
plot(ome1(i)*[1,1],yli,'k--','linewidth',1.2)
end
leg=legend('original spectrum','manipulated',2)
set(leg,'fontsize',13)
xlabel('frequency [cycles/day]','fontsize',fs)
ylabel('amplitude [arbitrary units]','fontsize',fs)

set(gca,'xminortick','on','fontsize',fs,'linewidth',2,'ticklength',[0.04 0.04])


filenam='/export/scratch/picture/eps/lspr_plot_spec'
%print('-depsc2','-painters',filenam );
%print('-djpeg','-painters',filenam );
%--------------------------------------------------
figure(1)

Fb=ifft(F);
yf=real(Fb);     % inverse Fourier transform    
% generation of 'time vector' xf belonging to 'time series' yf:
xf=x(1)+[0 (1:length(F))/(wk1(2)-wk1(1))/length(F)];
ind=find(xf <= x(end));
xf=xf(ind);
yf=yf(ind);

% window correction (rescaling to the state without windowing)
if win 
yf=yf./hamming(length(yf))';
end

% adjustment/scaling of yf by using the input series yo:    
%sc=mean(abs(yo-mean(yo)))/mean(abs(yf));  %not necessary
sc=1;
yf=sc*yf + real(F(1));



%begin of plotting of time series:

clf
xli=[20,48]
%yli=[min(yc)-20, max(yc)+20];
yli=[0,40];
lw=1.2
fs=13
subplot(4,1,1)
plot(xc/ndp,yc,'k','linewidth',lw)
text(xli(1)+1,yli(2)-6,'a)','fontsize',fs)
xlim(xli)
ylim(yli)
ylabel('y','fontsize',fs)

set(gca,'yminortick','on','xminortick','on','fontsize',fs,'linewidth',2,'ticklength',[0.03 0.03])


subplot(4,1,2)
plot(x/ndp,y,'r')
text(xli(1)+1,yli(2)-6,'b)','fontsize',fs)
xlim(xli)
ylim(yli)
ylabel('y','fontsize',fs)

set(gca,'yminortick','on','xminortick','on','fontsize',fs,'linewidth',2,'ticklength',[0.03 0.03])


subplot(4,1,3)

plot(xo/ndp,yo,'r')
hold on

plot(xc/ndp,yc,'k','linewidth',lw)
plot(xf/ndp,yf,'linewidth',lw)
text(xli(1)+1,yli(2)-6,'c)','fontsize',fs)
ylabel('y','fontsize',fs)
xlim(xli)
ylim(yli)

set(gca,'yminortick','on','xminortick','on','fontsize',fs,'linewidth',2,'ticklength',[0.03 0.03])

subplot(4,1,4)

plot(xo/ndp,yo,'r')
hold on
plot(xc/ndp,yc,'k','linewidth',3)
plot(xf/ndp,yf,'linewidth',lw)

ylabel('y','fontsize',fs)

xlabel('t [day]','fontsize',fs)
xlim([23,33])
ylim(yli)
text(23+.3,yli(2)-6,'d)','fontsize',fs)
set(gca,'yminortick','on','xminortick','on','fontsize',fs,'linewidth',2,'ticklength',[0.03 0.03])


filenam='/export/scratch/picture/eps/lspr_plot'
%print('-depsc2','-painters',filenam );
%print('-djpeg','-painters',filenam );
























